summaryrefslogtreecommitdiff
path: root/framework/Web/UI/TControl.php
diff options
context:
space:
mode:
authorxue <>2006-06-04 20:51:27 +0000
committerxue <>2006-06-04 20:51:27 +0000
commit112d86bb08a1dd4bde14005f757c95b0fc7a5a21 (patch)
tree61b601c9516944b58dd0025bb74829be8186f1e5 /framework/Web/UI/TControl.php
parent0f3a577bed4d828472469675e90fcab032e33f44 (diff)
Merge from 3.0 branch till 1140.
Diffstat (limited to 'framework/Web/UI/TControl.php')
-rw-r--r--framework/Web/UI/TControl.php9
1 files changed, 5 insertions, 4 deletions
diff --git a/framework/Web/UI/TControl.php b/framework/Web/UI/TControl.php
index 10541a37..eced51ea 100644
--- a/framework/Web/UI/TControl.php
+++ b/framework/Web/UI/TControl.php
@@ -591,6 +591,7 @@ class TControl extends TApplicationComponent implements IRenderable, IBindable
}
/**
+ * Sets a custom control attribute.
* @param string attribute name
* @param string value of the attribute
*/
@@ -1336,18 +1337,18 @@ class TControl extends TApplicationComponent implements IRenderable, IBindable
}
/**
* Invokes the parent's onBubbleEvent method.
* A control who wants to bubble an event must call this method in its onEvent method.
* @param TControl sender of the event
* @param TEventParameter event parameter
- * @see onBubbleEvent
+ * @see bubbleEvent
*/
protected function raiseBubbleEvent($sender,$param)
{
$control=$this;
while($control=$control->_parent)
{
- if($control->onBubbleEvent($sender,$param))
+ if($control->bubbleEvent($sender,$param))
break;
}
}
@@ -1361,7 +1362,7 @@ class TControl extends TApplicationComponent implements IRenderable, IBindable
* @return boolean true if the event bubbling is handled and no more bubbling.
* @see raiseBubbleEvent
*/
- public function onBubbleEvent($sender,$param)
+ public function bubbleEvent($sender,$param)
{
return false;
}
@@ -1336,18 +1337,18 @@ class TControl extends TApplicationComponent implements IRenderable, IBindable
}
/**
- * Invokes the parent's onBubbleEvent method.
+ * Invokes the parent's bubbleEvent method.
* A control who wants to bubble an event must call this method in its onEvent method.
* @param TControl sender of the event